==> insta_extractor-0.0.1.tar.gz: lib/src/utils/api_utils.dart <==
abstract class ApiUtils {
  static const String graphql = "graphql";
  static const String shortcodeMedia = "shortcode_media";
  static const String isVideo = "is_video";
  static const String displayUrl = "display_url";
  static const String videoUrl = "video_url";
  static const String profileUrl = "profile_pic_url";
  static const String user = "user";
  static const String username = "username";
  static const String fullName = "full_name";
  static const String edgeSidecarToChildren = "edge_sidecar_to_children";
  static const String edges = "edges";
  static const String node = "node";
  static const String cookie = "Cookie";
  static const String userAgent = "User-Agent";
  static const String mediaCount = "media_count";
  static const String items = "items";
  static const String mediaType = "media_type";
  static const String url = "url";
  static const String type = "type";
  static const String width = "width";
  static const String height = "height";
  static const String videoVersions = "video_versions";
  static const String tray = "tray";
  static const String pk = "pk";
  static const String reelFeed = "reel_feed";
  static const String candidates = "candidates";
  static const String imageVersions2 = "image_versions2";
  static const String profilePicUrl = "profile_pic_url";
  static const String owner = "owner";

  static const String USERAGENT =
      "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/93.0.4577.82 Safari/537.36";

  static const String STORY_USERAGENT =
      "Instagram 9.5.2 (iPhone7,2; iPhone OS 9_3_3; en_US; en-US; scale=2.00; 750x1334) AppleWebKit/420+";
}

==> insta_extractor-1.0.1.tar.gz: lib/src/utils/api_utils.dart <==
abstract class ApiUtils {
  static const String graphql = "graphql";
  static const String shortcodeMedia = "shortcode_media";
  static const String isVideo = "is_video";
  static const String displayUrl = "display_url";
  static const String videoUrl = "video_url";
  static const String profileUrl = "profile_pic_url";
  static const String user = "user";
  static const String username = "username";
  static const String fullName = "full_name";
  static const String edgeSidecarToChildren = "edge_sidecar_to_children";
  static const String edges = "edges";
  static const String node = "node";
  static const String cookie = "Cookie";
  static const String userAgent = "User-Agent";
  static const String mediaCount = "media_count";
  static const String items = "items";
  static const String mediaType = "media_type";
  static const String url = "url";
  static const String type = "type";
  static const String width = "width";
  static const String height = "height";
  static const String videoVersions = "video_versions";
  static const String tray = "tray";
  static const String pk = "pk";
  static const String feed = "feed";
  static const String candidates = "candidates";
  static const String imageVersions2 = "image_versions2";
  static const String profilePicUrl = "profile_pic_url";

  static const String USERAGENT = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/93.0.4577.82 Safari/537.36";

  static const String STORY_USERAGENT = "Instagram 9.5.2 (iPhone7,2; iPhone OS 9_3_3; en_US; en-US; scale=2.00; 750x1334) AppleWebKit/420+";

  static const ENDPOINT = 'https://instaapigram.herokuapp.com/media/';
}
